@@ -16,13 +16,15 @@
 
 #define QT_FEATURE_dynamicgl -1
 
-#define QT_FEATURE_opengl -1
+#define QT_FEATURE_opengl 1
 
-#define QT_FEATURE_vulkan -1
+#define QT_FEATURE_vulkan 1
+
+#define QT_FEATURE_metal -1
 
 #define QT_FEATURE_openvg -1
 
-#define QT_FEATURE_egl -1
+#define QT_FEATURE_egl 1
 
 #define QT_FEATURE_ico 1
 
@@ -30,7 +32,7 @@
 
 #define QT_FEATURE_xcb 1
 
-#define QT_FEATURE_xcb_glx_plugin -1
+#define QT_FEATURE_xcb_glx_plugin 1
 
 #define QT_FEATURE_texthtmlparser 1
 
@@ -106,8 +108,6 @@
 
 #define QT_FEATURE_undogroup 1
 
-#define QT_FEATURE_wayland -1
+#define QT_FEATURE_wayland 1
 
 #define QT_NO_ACCESSIBILITY_ATSPI_BRIDGE 1
-#define QT_NO_OPENGL 1
-#define QT_NO_EGL 1
